<map version="0.8.0">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node COLOR="#000000" CREATED="1158166424215" ID="Freemind_Link_1124266960" MODIFIED="1158167161470" TEXT="Konstrukt">
<font NAME="Tahoma" SIZE="20"/>
<hook NAME="accessories/plugins/AutomaticLayout.properties"/>
<node COLOR="#0033ff" CREATED="1158174618889" ID="Freemind_Link_1326931075" MODIFIED="1158174625929" POSITION="right" TEXT="notiz">
<font NAME="Tahoma" SIZE="18"/>
<node COLOR="#00b439" CREATED="1158174627341" ID="Freemind_Link_1719948098" MODIFIED="1158174638067" TEXT="+ / = ?">
<font NAME="Tahoma" SIZE="16"/>
</node>
<node COLOR="#00b439" CREATED="1158178365246" ID="Freemind_Link_239644892" MODIFIED="1158178370163" TEXT="link blah">
<font NAME="Tahoma" SIZE="16"/>
</node>
</node>
<node COLOR="#0033ff" CREATED="1158166431615" ID="_" MODIFIED="1158167161319" POSITION="right" TEXT="Name: Konstrukt">
<font NAME="Tahoma" SIZE="18"/>
</node>
<node COLOR="#0033ff" CREATED="1158167123575" FOLDED="true" ID="Freemind_Link_603120795" MODIFIED="1158167161349" POSITION="right" TEXT="Grundidee">
<font NAME="Tahoma" SIZE="18"/>
<node COLOR="#00b439" CREATED="1158167128612" FOLDED="true" ID="Freemind_Link_833470606" MODIFIED="1158167161369" TEXT="Nutzung von speziellen Tags">
<font NAME="Tahoma" SIZE="16"/>
<node COLOR="#990000" CREATED="1158167164975" ID="Freemind_Link_185741730" MODIFIED="1158167174979" TEXT="Strukturierung/Modularisierung des Inhalts">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158167176341" ID="Freemind_Link_444254903" MODIFIED="1158167180076" TEXT="template">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
<node COLOR="#990000" CREATED="1158167185925" ID="Freemind_Link_338600523" MODIFIED="1158167187377" TEXT="Dynamik">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158167188338" ID="Freemind_Link_644575419" MODIFIED="1158167190261" TEXT="perl">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167190511" ID="Freemind_Link_1721685220" MODIFIED="1158167191673" TEXT="if">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167192484" ID="Freemind_Link_1098479331" MODIFIED="1158167194707" TEXT="env">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167194998" ID="Freemind_Link_167876331" MODIFIED="1158167201507" TEXT="param">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
</node>
<node COLOR="#00b439" CREATED="1158167278227" ID="Freemind_Link_1416513129" MODIFIED="1158167281252" TEXT="Designziele">
<font NAME="Tahoma" SIZE="16"/>
<node COLOR="#990000" CREATED="1158167283745" FOLDED="true" ID="Freemind_Link_1395691127" MODIFIED="1158167290866" TEXT="Schnelle Entwicklung">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158167341418" ID="Freemind_Link_1790453732" MODIFIED="1158167358363" TEXT="Templating">
<font NAME="Tahoma" SIZE="12"/>
<node COLOR="#111111" CREATED="1158167399532" ID="Freemind_Link_5596908" MODIFIED="1158167413302" TEXT="Beliebig tiefe Verschachtelung der Templates m&#xf6;glich">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167360846" ID="Freemind_Link_634373928" MODIFIED="1158167381876" TEXT="Sehr gute Modularisierungsm&#xf6;glichkeiten des Markups">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167382998" ID="Freemind_Link_1749046430" MODIFIED="1158167394354" TEXT="Markup wird fast nie zwei mal geschrieben">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
<node COLOR="#111111" CREATED="1158167435253" ID="Freemind_Link_1039758952" MODIFIED="1158167453159" TEXT="Breite Palette vorhandener Plugins (blog, wiki)">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167502700" ID="Freemind_Link_1038144922" MODIFIED="1158167518533" TEXT="&quot;Einfache&quot; Entwicklung eigener Anwendungen/Plugins">
<font NAME="Tahoma" SIZE="12"/>
<node COLOR="#111111" CREATED="1158167519815" ID="Freemind_Link_24267395" MODIFIED="1158167539233" TEXT="Viel &quot;Drecksarbeit&quot; wird vom Framework &#xfc;bernommen">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167541676" ID="Freemind_Link_359225785" MODIFIED="1158167556948" TEXT="Wiederverwendung vorhandener Plugins/Module">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167561605" ID="Freemind_Link_36332977" MODIFIED="1158167563508" TEXT="CPAN">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
</node>
<node COLOR="#990000" CREATED="1158167296404" FOLDED="true" ID="Freemind_Link_1890350822" MODIFIED="1158168824107" TEXT="Trennung von Code, Markup und Inhalt">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158167570217" ID="Freemind_Link_1533518837" MODIFIED="1158167583607" TEXT="Kontroll-Logik: Plugins">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167584207" ID="Freemind_Link_1365990500" MODIFIED="1158167590557" TEXT="Markup: Templates">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158167591077" ID="Freemind_Link_1262263405" MODIFIED="1158167626218" TEXT="Inhalt/Daten: DBI/MySQL">
<font NAME="Tahoma" SIZE="12"/>
<node COLOR="#111111" CREATED="1158167627199" ID="Freemind_Link_443596731" MODIFIED="1158167651664" TEXT="Jedes Plugin ist so entwickelt, dass einfach eigene Backends geschrieben werden k&#xf6;nnen">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
</node>
<node COLOR="#990000" CREATED="1158167309853" FOLDED="true" ID="Freemind_Link_615558919" MODIFIED="1158167319106" TEXT="Wiederverwending von Code und Markup">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158167705912" ID="Freemind_Link_1310091585" MODIFIED="1158167726853" TEXT="Markup und Templates k&#xf6;nnen &#xfc;ber mehrere Websites hinweg weitgehend unver&#xe4;ndert weigergenutzt werden.">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
<node COLOR="#990000" CREATED="1158167323312" FOLDED="true" ID="Freemind_Link_1698752268" MODIFIED="1158167326317" TEXT="Sauberer Code">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158168810017" ID="Freemind_Link_290831597" MODIFIED="1158168824107" TEXT="Siehe auch">
<arrowlink DESTINATION="Freemind_Link_1890350822" ENDARROW="Default" ENDINCLINATION="77;14;" ID="Freemind_Arrow_Link_1341306546" STARTARROW="None" STARTINCLINATION="98;-7;"/>
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158168843374" ID="Freemind_Link_1235010009" MODIFIED="1158168853950" TEXT="Komplett objektorientiert">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158168871875" ID="Freemind_Link_1136694907" MODIFIED="1158168881029" TEXT="Viel Dokumentation: Sch&#xe4;tzungsweise 1:1">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158168890202" ID="Freemind_Link_1776811294" MODIFIED="1158168899746" TEXT="Wenige globale Variablen">
<font NAME="Tahoma" SIZE="12"/>
<node COLOR="#111111" CREATED="1158168900677" ID="Freemind_Link_233060127" MODIFIED="1158168914266" TEXT="Nur wo es eine wesentliche Vereinfachung darstellt">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158168916219" ID="Freemind_Link_1630435862" MODIFIED="1158168920946" TEXT="Nicht aus Faulheit">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
<node COLOR="#111111" CREATED="1158168923820" ID="Freemind_Link_471438126" MODIFIED="1158168928877" TEXT="use strict; use warnings;">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
<node COLOR="#990000" CREATED="1158167326657" FOLDED="true" ID="Freemind_Link_1903855905" MODIFIED="1158167335179" TEXT="Performance">
<font NAME="Tahoma" SIZE="14"/>
<node COLOR="#111111" CREATED="1158168935998" ID="Freemind_Link_231146080" MODIFIED="1158168941095" TEXT="&quot;Kluges&quot; Caching">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158168941385" ID="Freemind_Link_416399245" MODIFIED="1158168947214" TEXT="2-Phasen Ausf&#xfc;hrung">
<font NAME="Tahoma" SIZE="12"/>
<node COLOR="#111111" CREATED="1158168952361" ID="Freemind_Link_1154599946" MODIFIED="1158168973211" TEXT="Statische Ergebnisse werden identifiziert und kompiliert">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158168974323" ID="Freemind_Link_1787806783" MODIFIED="1158168991628" TEXT="Nur die bei jedem Aufruf ver&#xe4;nderlichen Inhalte werden auch neu berechnet">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158169002093" ID="Freemind_Link_1471459812" MODIFIED="1158169009654" TEXT="Caching der geparsten Templates">
<font NAME="Tahoma" SIZE="12"/>
</node>
<node COLOR="#111111" CREATED="1158169022262" ID="Freemind_Link_394751223" MODIFIED="1158169033137" TEXT="Nachteil: Macht die Programmierung etwas komplizierter">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
<node COLOR="#111111" CREATED="1158169038175" ID="Freemind_Link_389692782" MODIFIED="1158169040949" TEXT="mod_perl">
<font NAME="Tahoma" SIZE="12"/>
</node>
</node>
</node>
</node>
<node COLOR="#0033ff" CREATED="1158167079281" FOLDED="true" ID="Freemind_Link_863403145" MODIFIED="1158167161389" POSITION="right" TEXT="Vorhandene Plugins">
<font NAME="Tahoma" SIZE="18"/>
<node COLOR="#00b439" CREATED="1158167089196" ID="Freemind_Link_1457557276" MODIFIED="1158167161419" TEXT="Low Level">
<font NAME="Tahoma" SIZE="16"/>
<node COLOR="#990000" CREATED="1158167229728" ID="Freemind_Link_102062595" MODIFIED="1158167233864" TEXT="template">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158167234815" ID="Freemind_Link_919088883" MODIFIED="1158169065814" TEXT="formvalidator">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158169070301" ID="Freemind_Link_1617676227" MODIFIED="1158169073475" TEXT="mail::obfuscator">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158169086584" ID="Freemind_Link_1400244602" MODIFIED="1158169087616" TEXT="sql">
<font NAME="Tahoma" SIZE="14"/>
</node>
</node>
<node COLOR="#00b439" CREATED="1158167093151" ID="Freemind_Link_746646931" MODIFIED="1158167161429" TEXT="High Level">
<font NAME="Tahoma" SIZE="16"/>
<node COLOR="#990000" CREATED="1158167239372" ID="Freemind_Link_1559291714" MODIFIED="1158167240093" TEXT="blog">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158167249196" ID="Freemind_Link_490575466" MODIFIED="1158167250327" TEXT="wiki">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158167256586" ID="Freemind_Link_25456390" MODIFIED="1158167258018" TEXT="calendar">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158167240393" ID="Freemind_Link_1186888766" MODIFIED="1158167245230" TEXT="guestbook">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158169104800" ID="Freemind_Link_711011985" MODIFIED="1158169106162" TEXT="hitstats">
<font NAME="Tahoma" SIZE="14"/>
</node>
<node COLOR="#990000" CREATED="1158169106413" ID="Freemind_Link_1270878545" MODIFIED="1158169108376" TEXT="usermanagement">
<font NAME="Tahoma" SIZE="14"/>
</node>
</node>
</node>
<node COLOR="#0033ff" CREATED="1158167457846" ID="Freemind_Link_799978361" MODIFIED="1158167460630" POSITION="right" TEXT="Anwendungen">
<font NAME="Tahoma" SIZE="18"/>
<node COLOR="#00b439" CREATED="1158167461811" ID="Freemind_Link_1894393153" MODIFIED="1158167465437" TEXT="notfallhunde.de">
<font NAME="Tahoma" SIZE="16"/>
</node>
<node COLOR="#00b439" CREATED="1158167465837" ID="Freemind_Link_1179413538" MODIFIED="1158167468761" TEXT="gedankenkonstrukt.de">
<font NAME="Tahoma" SIZE="16"/>
</node>
<node COLOR="#00b439" CREATED="1158167469182" ID="Freemind_Link_1358252891" MODIFIED="1158167474910" TEXT="motorrad-wittek.de">
<font NAME="Tahoma" SIZE="16"/>
</node>
<node COLOR="#00b439" CREATED="1158167475341" ID="Freemind_Link_1308386584" MODIFIED="1158167483883" TEXT="anicheck.de / anipool.de">
<font NAME="Tahoma" SIZE="16"/>
</node>
</node>
<node COLOR="#0033ff" CREATED="1158173636587" ID="Freemind_Link_1120140212" MODIFIED="1158173650517" POSITION="right" TEXT="Caching">
<font NAME="Tahoma" SIZE="18"/>
</node>
</node>
</map>
